# Generated by roxygen2: do not edit by hand

export(bereken_rendement)
export(bereken_studiewissel)
export(bereken_uitval)
export(combineer_indicatoren)
export(maak_basisbestand)
export(maak_diploma_behaald)
export(maak_instroom_cohort)
export(start_dashboard)
importFrom(rlang,":=")
importFrom(rlang,.data)
