#' staat1cho: Studie-indicatoren op basis van 1CHO-data
#'
#' Berekent instroom-, rendement-, uitval- en studiewisselindicatoren
#' vanuit de 1CHO-aanlevering van DUO.
#'
#' @importFrom rlang .data :=
#' @name staat1cho-package
#' @keywords internal
"_PACKAGE"

utils::globalVariables(c(
  "croho_onderdeel_actuele_opleiding",
  "croho_onderdeel_actuele_opleiding_label",
  "diploma",
  "diploma_een_drie",
  "diplomajaar",
  "eerstejaar_instelling",
  "geslacht",
  "geslacht_label",
  "indicatie_eer_actueel",
  "indicatie_eer_actueel_label",
  "indicatie_internationale_student",
  "indicatie_internationale_student_label",
  "inschrijvingsjaar",
  "jaar_eerste_diploma",
  "laatste_jaar_inschrijving",
  "leeftijd_per_peildatum_1_oktober",
  "locatie",
  "locatie_label",
  "opl_dubbel",
  "opleiding_actueel_equivalent",
  "opleidingscode",
  "opleidingsniveau",
  "opleidingsvorm",
  "opleidingsvorm_label",
  "persnr_dubbel",
  "persoonsgebonden_nummer",
  "postcode4_student_1okt",
  "postcode4_vooropleiding_voorHO",
  "postcodecijfers_student_op_1_oktober",
  "postcodecijfers_van_de_hoogste_vooropl_voor_het_ho",
  "rendement_3jr",
  "rendement_8jr",
  "sector",
  "sector_na_switch3jr",
  "soort_diploma_instelling",
  "soort_diploma_instelling_label",
  "soort_hoger_onderwijs",
  "soort_inschrijving_actuele_instelling",
  "soort_inschrijving_actuele_instelling_label",
  "status",
  "studiewissel_1jr",
  "studiewissel_3jr",
  "type_hoger_onderwijs_binnen_soort_hoger_onderwijs",
  "uitval_een_drie",
  "uitval_xjr",
  "verblijfsjaar_actuele_instelling",
  "verblijfsjaar_eerste_diploma",
  "verschil_kalenderjaren",
  "vestigingsnummer_gemeentenaam_volgens_rio"
))
