% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instroom.R
\name{maak_instroom_cohort}
\alias{maak_instroom_cohort}
\title{Maak een eerstejaarscohort per instelling}
\usage{
maak_instroom_cohort(basisbestand, soort_ho)
}
\arguments{
\item{basisbestand}{Tibble zoals gemaakt door \code{\link[=maak_basisbestand]{maak_basisbestand()}}}

\item{soort_ho}{Character vector met toegestane waarden van
\code{soort_hoger_onderwijs}, bijv. \code{c("hoger beroepsonderwijs", "hbo")}}
}
\value{
Een tibble met één rij per student, aangevuld met kolom
\code{eerstejaar_instelling} (= inschrijvingsjaar). Gooit een fout als er
dubbele persoonsgebonden nummers zijn.
}
\description{
Filtert het basisbestand op het opgegeven soort hoger onderwijs,
hoofdinschrijvingen en eerste verblijfsjaar.
}
\examples{
basis <- tibble::tibble(
  persoonsgebonden_nummer = c("S1", "S2", "S3"),
  soort_hoger_onderwijs = c("hbo", "wo", "hbo"),
  soort_inschrijving_actuele_instelling_label =
    "hoofdinschrijving binnen het domein actuele instelling",
  verblijfsjaar_actuele_instelling = 1L,
  inschrijvingsjaar = 2020L,
  soort_diploma_instelling_label = NA_character_
)
maak_instroom_cohort(basis, "hbo")
}
