% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rendement.R
\name{maak_diploma_behaald}
\alias{maak_diploma_behaald}
\title{Maak een bestand met het vroegst behaalde diploma per student}
\usage{
maak_diploma_behaald(basisbestand)
}
\arguments{
\item{basisbestand}{Tibble zoals gemaakt door \code{\link[=maak_basisbestand]{maak_basisbestand()}}}
}
\value{
Een tibble met één rij per student met kolommen
\code{persoonsgebonden_nummer}, \code{jaar_eerste_diploma},
\code{verblijfsjaar_eerste_diploma} en \code{diploma}. Gooit een fout bij
dubbele persoonsgebonden nummers.
}
\description{
Filtert het basisbestand op diplomasoorten die gelden als afgeronde opleiding
en behoudt per student alleen het eerste diploma op basis van diplomajaar.
}
\examples{
basis <- tibble::tibble(
  persoonsgebonden_nummer = c("S1", "S2"),
  soort_diploma_instelling = c(
    "Hoofd-bachelor-diploma binnen de actuele instelling",
    NA_character_
  ),
  diplomajaar = c(2022L, NA_integer_),
  verblijfsjaar_actuele_instelling = c(3L, 1L)
)
maak_diploma_behaald(basis)
}
