% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/studiewissel.R
\name{bereken_studiewissel}
\alias{bereken_studiewissel}
\title{Bereken studiewisselindicatoren per cohort}
\usage{
bereken_studiewissel(
  basisbestand,
  cohorten_instroom,
  diploma_behaald,
  uitval_indicatoren
)
}
\arguments{
\item{basisbestand}{Tibble zoals gemaakt door \code{\link[=maak_basisbestand]{maak_basisbestand()}}}

\item{cohorten_instroom}{Tibble zoals gemaakt door \code{\link[=maak_instroom_cohort]{maak_instroom_cohort()}}}

\item{diploma_behaald}{Tibble zoals gemaakt door \code{\link[=maak_diploma_behaald]{maak_diploma_behaald()}}}

\item{uitval_indicatoren}{Tibble zoals gemaakt door \code{\link[=bereken_uitval]{bereken_uitval()}}}
}
\value{
Een tibble met kolommen \code{persoonsgebonden_nummer},
\code{studiewissel_1jr}, \code{studiewissel_3jr} (factoren) en aanvullende
switch-kolommen met de opleiding, opleidingsvorm, niveau en sector na
de wissel
}
\description{
Bepaalt per student of zij binnen 1 of 3 jaar van opleiding zijn gewisseld.
Studenten die al zijn uitgevallen of gediplomeerd in de meetperiode worden
buiten beschouwing gelaten.
}
\examples{
basis <- tibble::tibble(
  persoonsgebonden_nummer = c("S1", "S1"),
  verblijfsjaar_actuele_instelling = c(1L, 2L),
  soort_inschrijving_actuele_instelling_label =
    "hoofdinschrijving binnen het domein actuele instelling",
  opleiding_actueel_equivalent = "34401",
  inschrijvingsjaar = c(2020L, 2021L),
  opleidingsvorm = "voltijd",
  type_hoger_onderwijs_binnen_soort_hoger_onderwijs = "bachelor",
  croho_onderdeel_actuele_opleiding = "techniek"
)
cohort <- tibble::tibble(
  persoonsgebonden_nummer = "S1",
  inschrijvingsjaar = 2020L,
  eerstejaar_instelling = 2020L,
  soort_diploma_instelling_label = NA_character_,
  opleidingsvorm_label = "voltijd"
)
diploma <- tibble::tibble(
  persoonsgebonden_nummer = character(0),
  jaar_eerste_diploma = integer(0),
  verblijfsjaar_eerste_diploma = integer(0),
  diploma = character(0)
)
uitval <- tibble::tibble(
  persoonsgebonden_nummer = "S1",
  uitval_xjr = NA_real_
)
bereken_studiewissel(basis, cohort, diploma, uitval)
}
