% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instroom.R
\name{maak_basisbestand}
\alias{maak_basisbestand}
\title{Lees het 1CHO-bestand in en voeg label-kolommen toe}
\usage{
maak_basisbestand(pad_invoer)
}
\arguments{
\item{pad_invoer}{Pad naar het semicolongescheiden CSV-bestand (UTF-8)}
}
\value{
Een tibble met alle 1CHO-regels plus extra \verb{_label}-kolommen die de
originele categorische waarden bewaren voor gebruik in rapportages
}
\description{
Leest een semicolongescheiden CSV-bestand (UTF-8) in en voegt
extra \verb{_label}-kolommen toe voor gebruik in rapportages. Het pakket
bevat een klein synthetisch voorbeeldbestand zonder echte persoonsgegevens
(\code{inst/extdata/voorbeeld_1cho.csv}).
}
\examples{
# voorbeeld_1cho.csv is a small synthetic dataset bundled with the package
pad <- system.file("extdata/voorbeeld_1cho.csv", package = "staat1cho")
basis <- suppressMessages(maak_basisbestand(pad))
}
